@@ -1,12 +1,6 @@
 package Person::SimpleAddress;
-
 use warnings;
 use strict;
-
 use base 'Class::Accessor::Complex';
-
-__PACKAGE__
-    ->mk_new
-    ->mk_scalar_accessors(qw(fulladdr));
-
+__PACKAGE__->mk_new->mk_scalar_accessors(qw(fulladdr));
 1;
